@@ -22,7 +22,7 @@
 #       Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA
 #
 
-VERSION=3.2.9
+VERSION=3.4.6
 
 usage() # $1 = exit status
 {
@@ -213,10 +213,6 @@ cd "$(dirname $0)"
 
 echo "Installing Shorewall Version $VERSION"
 
-#
-# First do Backups
-#
-
 #
 # Check for /etc/shorewall
 #
@@ -239,7 +235,7 @@ echo "shorewall control program installed in ${PREFIX}/sbin/shorewall"
 # Install the Firewall Script
 #
 if [ -n "$DEBIAN" ]; then
-    install_file_with_backup init.debian.sh ${PREFIX}/etc/init.d/shorewall 0544 ${PREFIX}/usr/share/shorewall-${VERSION}.bkout
+    install_file_with_backup init.debian.sh /etc/init.d/shorewall 0544 ${PREFIX}/usr/share/shorewall-${VERSION}.bkout
 elif [ -n "$ARCHLINUX" ]; then
     install_file_with_backup init.archlinux.sh ${PREFIX}${DEST}/$INIT 0544 ${PREFIX}/usr/share/shorewall-${VERSION}.bkout
 
@@ -260,7 +256,6 @@ mkdir -p ${PREFIX}/var/lib/shorewall
 chmod 755 ${PREFIX}/etc/shorewall
 chmod 755 ${PREFIX}/usr/share/shorewall
 chmod 755 ${PREFIX}/usr/share/shorewall/configfiles
-
 #
 # Install the config file
 #
@@ -287,14 +282,6 @@ if [ ! -f ${PREFIX}/etc/shorewall/zones ]; then
     echo "Zones file installed as ${PREFIX}/etc/shorewall/zones"
 fi
 
-#
-# Install the functions file
-#
-
-install_file functions ${PREFIX}/usr/share/shorewall/functions 0444
-
-echo "Common functions installed in ${PREFIX}/usr/share/shorewall/functions"
-
 #
 # Install the Compiler
 #
@@ -304,11 +291,14 @@ install_file compiler ${PREFIX}/usr/share/shorewall/compiler 0555
 echo
 echo "Compiler installed in ${PREFIX}/usr/share/shorewall/compiler"
 
-# Install the Help file
 #
-install_file help ${PREFIX}/usr/share/shorewall/help 0555
+# Install wait4ifup
+#
 
-echo "Help command executor installed in ${PREFIX}/usr/share/shorewall/help"
+install_file wait4ifup ${PREFIX}/usr/share/shorewall/wait4ifup 0555
+
+echo
+echo "wait4ifup installed in ${PREFIX}/usr/share/shorewall/wait4ifup"
 
 #
 # Install the policy file
@@ -379,7 +369,9 @@ fi
 #
 run_install $OWNERSHIP -m 0644 params ${PREFIX}/usr/share/shorewall/configfiles/params
 
-if [ ! -f ${PREFIX}/etc/shorewall/params ]; then
+if [ -f ${PREFIX}/etc/shorewall/params ]; then
+    chmod 0644 ${PREFIX}/etc/shorewall/params
+else
     run_install $OWNERSHIP -m 0644 params ${PREFIX}/etc/shorewall/params
     echo "Parameter file installed as ${PREFIX}/etc/shorewall/params"
 fi
@@ -472,12 +464,15 @@ delete_file ${PREFIX}/etc/shorewall/routes
 
 delete_file ${PREFIX}/usr/share/shorewall/tcstart
 
+#
+# Delete the Limits Files
+#
+delete_file ${PREFIX}/usr/share/shorewall/action.Limit
+delete_file ${PREFIX}/usr/share/shorewall/Limit
 #
 # Delete the xmodules file
 #
-
 delete_file ${PREFIX}/usr/share/shorewall/xmodules
-
 #
 # Install the Providers file
 #
@@ -626,9 +621,9 @@ if [ ! -f ${PREFIX}/etc/shorewall/actions ]; then
 fi
 
 #
-# Install the  Makefile
+# Install the  Makefiles
 #
-run_install $OWNERSHIP -m 0644 Makefile ${PREFIX}/usr/share/shorewall/configfiles/Makefile
+run_install $OWNERSHIP -m 0644 Makefile-lite ${PREFIX}/usr/share/shorewall/configfiles/Makefile
 run_install $OWNERSHIP -m 0600 Makefile ${PREFIX}/etc/shorewall/Makefile
 echo "Makefile installed as ${PREFIX}/etc/shorewall/Makefile"
 
@@ -640,9 +635,6 @@ for f in action.* ; do
     echo "Action ${f#*.} file installed as ${PREFIX}/usr/share/shorewall/$f"
 done
 
-install_file Limit ${PREFIX}/usr/share/shorewall/Limit 0644
-echo "Limit action extension script installed as ${PREFIX}/usr/share/shorewall/Limit"
-#
 # Install the Macro files
 #
 for f in macro.* ; do
@@ -650,6 +642,19 @@ for f in macro.* ; do
     echo "Macro ${f#*.} file installed as ${PREFIX}/usr/share/shorewall/$f"
 done
 #
+# Install the libraries
+#
+for f in lib.* ; do
+    if [ -f $f ]; then
+	install_file $f ${PREFIX}/usr/share/shorewall/$f 0644
+	echo "Library ${f#*.} file installed as ${PREFIX}/usr/share/shorewall/$f"
+    fi
+done
+#
+# Symbolically link 'functions' to lib.base
+#
+ln -sf lib.base ${PREFIX}/usr/share/shorewall/functions
+#
 # Install the program skeleton files
 #
 for f in prog.* ; do
@@ -670,6 +675,28 @@ if [ -z "$PREFIX" ]; then
     ln -s ${DEST}/${INIT} /usr/share/shorewall/init
 fi
 
+#
+# Install the Man Pages
+#
+
+cd manpages
+
+for f in *.5; do
+    gzip -c $f > $f.gz
+    run_install -D  -m 0444 $f.gz ${PREFIX}/usr/share/man/man5/$f.gz
+    echo "Man page $f.gz installed to /usr/share/man/man5/$f.gz"
+done
+
+for f in *.8; do
+    gzip -c $f > $f.gz
+    run_install -D  -m 0444 $f.gz ${PREFIX}/usr/share/man/man8/$f.gz
+    echo "Man page $f.gz installed to /usr/share/man/man8/$f.gz"
+done
+
+cd ..
+
+echo "Man Pages Installed"
+
 #
 # Install the firewall script
 #
